@@ -19,8 +19,8 @@
 
 /**
  * @file git2/remote.h
- * @brief Git remote management functions
- * @defgroup git_remote remote management functions
+ * @brief Remotes are where local repositories fetch from and push to
+ * @defgroup git_remote Remotes are where local repositories fetch from and push to
  * @ingroup Git
  * @{
  */
@@ -76,6 +76,17 @@ typedef enum {
 	GIT_REMOTE_CREATE_SKIP_DEFAULT_FETCHSPEC = (1 << 1)
 } git_remote_create_flags;
 
+/**
+ * How to handle reference updates.
+ */
+typedef enum {
+	/* Write the fetch results to FETCH_HEAD. */
+	GIT_REMOTE_UPDATE_FETCHHEAD = (1 << 0),
+
+	/* Report unchanged tips in the update_refs callback. */
+	GIT_REMOTE_UPDATE_REPORT_UNCHANGED = (1 << 1)
+} git_remote_update_flags;
+
 /**
  * Remote creation options structure
  *
@@ -105,7 +116,10 @@ typedef struct git_remote_create_options {
 	unsigned int flags;
 } git_remote_create_options;
 
+/** Current version for the `git_remote_create_options` structure */
 #define GIT_REMOTE_CREATE_OPTIONS_VERSION 1
+
+/** Static constructor for `git_remote_create_options` */
 #define GIT_REMOTE_CREATE_OPTIONS_INIT {GIT_REMOTE_CREATE_OPTIONS_VERSION}
 
 /**
@@ -455,7 +469,15 @@ typedef enum git_remote_completion_t {
 	GIT_REMOTE_COMPLETION_ERROR
 } git_remote_completion_t;
 
-/** Push network progress notification function */
+/**
+ * Push network progress notification callback.
+ *
+ * @param current The number of objects pushed so far
+ * @param total The total number of objects to push
+ * @param bytes The number of bytes pushed
+ * @param payload The user-specified payload callback
+ * @return 0 or an error code to stop the transfer
+ */
 typedef int GIT_CALLBACK(git_push_transfer_progress_cb)(
 	unsigned int current,
 	unsigned int total,
@@ -491,8 +513,12 @@ typedef struct {
  * as commands to the destination.
  * @param len number of elements in `updates`
  * @param payload Payload provided by the caller
+ * @return 0 or an error code to stop the push
  */
-typedef int GIT_CALLBACK(git_push_negotiation)(const git_push_update **updates, size_t len, void *payload);
+typedef int GIT_CALLBACK(git_push_negotiation)(
+	const git_push_update **updates,
+	size_t len,
+	void *payload);
 
 /**
  * Callback used to inform of the update status from the remote.
@@ -557,7 +583,8 @@ struct git_remote_callbacks {
 	 * Completion is called when different parts of the download
 	 * process are done (currently unused).
 	 */
-	int GIT_CALLBACK(completion)(git_remote_completion_t type, void *data);
+	int GIT_CALLBACK(completion)(git_remote_completion_t type,
+		void *data);
 
 	/**
 	 * This will be called if the remote host requires
@@ -583,11 +610,22 @@ struct git_remote_callbacks {
 	 */
 	git_indexer_progress_cb transfer_progress;
 
+#ifdef GIT_DEPRECATE_HARD
+	void *reserved_update_tips;
+#else
 	/**
-	 * Each time a reference is updated locally, this function
-	 * will be called with information about it.
+	 * Deprecated callback for reference updates, callers should
+	 * set `update_refs` instead. This is retained for backward
+	 * compatibility; if you specify both `update_refs` and
+	 * `update_tips`, then only the `update_refs` function will
+	 * be called.
+	 *
+	 * @deprecated the `update_refs` callback in this structure
+	 * should be preferred
 	 */
-	int GIT_CALLBACK(update_tips)(const char *refname, const git_oid *a, const git_oid *b, void *data);
+	int GIT_CALLBACK(update_tips)(const char *refname,
+		const git_oid *a, const git_oid *b, void *data);
+#endif
 
 	/**
 	 * Function to call with progress information during pack
@@ -644,9 +682,25 @@ struct git_remote_callbacks {
 	 */
 	git_url_resolve_cb resolve_url;
 #endif
+
+	/**
+	 * Each time a reference is updated locally, this function
+	 * will be called with information about it. This should be
+	 * preferred over the `update_tips` callback in this
+	 * structure.
+	 */
+	int GIT_CALLBACK(update_refs)(
+		const char *refname,
+		const git_oid *a,
+		const git_oid *b,
+		git_refspec *spec,
+		void *data);
 };
 
+/** Current version for the `git_remote_callbacks_options` structure */
 #define GIT_REMOTE_CALLBACKS_VERSION 1
+
+/** Static constructor for `git_remote_callbacks_options` */
 #define GIT_REMOTE_CALLBACKS_INIT {GIT_REMOTE_CALLBACKS_VERSION}
 
 /**
@@ -733,10 +787,9 @@ typedef struct {
 	git_fetch_prune_t prune;
 
 	/**
-	 * Whether to write the results to FETCH_HEAD. Defaults to
-	 * on. Leave this default in order to behave like git.
+	 * How to handle reference updates; see `git_remote_update_flags`.
 	 */
-	int update_fetchhead;
+	unsigned int update_fetchhead;
 
 	/**
 	 * Determines how to behave regarding tags on the remote, such
@@ -774,9 +827,17 @@ typedef struct {
 	git_strarray custom_headers;
 } git_fetch_options;
 
+/** Current version for the `git_fetch_options` structure */
 #define GIT_FETCH_OPTIONS_VERSION 1
-#define GIT_FETCH_OPTIONS_INIT { GIT_FETCH_OPTIONS_VERSION, GIT_REMOTE_CALLBACKS_INIT, GIT_FETCH_PRUNE_UNSPECIFIED, 1, \
-				 GIT_REMOTE_DOWNLOAD_TAGS_UNSPECIFIED, GIT_PROXY_OPTIONS_INIT }
+
+/** Static constructor for `git_fetch_options` */
+#define GIT_FETCH_OPTIONS_INIT { \
+	GIT_FETCH_OPTIONS_VERSION, \
+	GIT_REMOTE_CALLBACKS_INIT, \
+	GIT_FETCH_PRUNE_UNSPECIFIED, \
+	GIT_REMOTE_UPDATE_FETCHHEAD, \
+	GIT_REMOTE_DOWNLOAD_TAGS_UNSPECIFIED, \
+	GIT_PROXY_OPTIONS_INIT }
 
 /**
  * Initialize git_fetch_options structure
@@ -830,9 +891,17 @@ typedef struct {
 	 * Extra headers for this push operation
 	 */
 	git_strarray custom_headers;
+
+	/**
+	 * "Push options" to deliver to the remote.
+	 */
+	git_strarray remote_push_options;
 } git_push_options;
 
+/** Current version for the `git_push_options` structure */
 #define GIT_PUSH_OPTIONS_VERSION 1
+
+/** Static constructor for `git_push_options` */
 #define GIT_PUSH_OPTIONS_INIT { GIT_PUSH_OPTIONS_VERSION, 1, GIT_REMOTE_CALLBACKS_INIT, GIT_PROXY_OPTIONS_INIT }
 
 /**
@@ -876,7 +945,10 @@ typedef struct {
 	git_strarray custom_headers;
 } git_remote_connect_options;
 
+/** Current version for the `git_remote_connect_options` structure */
 #define GIT_REMOTE_CONNECT_OPTIONS_VERSION 1
+
+/** Static constructor for `git_remote_connect_options` */
 #define GIT_REMOTE_CONNECT_OPTIONS_INIT { \
 	GIT_REMOTE_CONNECT_OPTIONS_VERSION, \
 	GIT_REMOTE_CALLBACKS_INIT, \
@@ -996,20 +1068,20 @@ GIT_EXTERN(int) git_remote_upload(
  * `git_remote_connect` will be used (if it was called).
  *
  * @param remote the remote to update
+ * @param callbacks  pointer to the callback structure to use or NULL
+ * @param update_flags the git_remote_update_flags for these tips.
+ * @param download_tags what the behaviour for downloading tags is for this fetch. This is
+ * ignored for push. This must be the same value passed to `git_remote_download()`.
  * @param reflog_message The message to insert into the reflogs. If
  * NULL and fetching, the default is "fetch <name>", where <name> is
  * the name of the remote (or its url, for in-memory remotes). This
  * parameter is ignored when pushing.
- * @param callbacks  pointer to the callback structure to use or NULL
- * @param update_fetchhead whether to write to FETCH_HEAD. Pass 1 to behave like git.
- * @param download_tags what the behaviour for downloading tags is for this fetch. This is
- * ignored for push. This must be the same value passed to `git_remote_download()`.
  * @return 0 or an error code
  */
 GIT_EXTERN(int) git_remote_update_tips(
 		git_remote *remote,
 		const git_remote_callbacks *callbacks,
-		int update_fetchhead,
+		unsigned int update_flags,
 		git_remote_autotag_option_t download_tags,
 		const char *reflog_message);
 
@@ -1071,6 +1143,9 @@ GIT_EXTERN(int) git_remote_push(
 
 /**
  * Get the statistics structure that is filled in by the fetch operation.
+ *
+ * @param remote the remote to get statistics for
+ * @return the git_indexer_progress for the remote
  */
 GIT_EXTERN(const git_indexer_progress *) git_remote_stats(git_remote *remote);
 
@@ -1170,4 +1245,5 @@ GIT_EXTERN(int) git_remote_default_branch(git_buf *out, git_remote *remote);
 
 /** @} */
 GIT_END_DECL
+
 #endif
