@@ -96,7 +96,7 @@ static void assert_all_refnames_match(const char **expected, git_vector *names)
 	}
 	cl_assert(expected[i] == NULL);
 
-	git_vector_free(names);
+	git_vector_dispose(names);
 }
 
 void test_refs_iterator__list(void)
@@ -129,7 +129,7 @@ void test_refs_iterator__empty(void)
 	git_repository *empty;
 
 	cl_git_pass(git_odb__new(&odb, NULL));
-	cl_git_pass(git_repository__wrap_odb(&empty, odb, GIT_OID_SHA1));
+	cl_git_pass(git_repository_wrap_odb(&empty, odb));
 
 	cl_git_pass(git_reference_iterator_new(&iter, empty));
 	cl_assert_equal_i(GIT_ITEROVER, git_reference_next(&ref, iter));
@@ -222,7 +222,7 @@ void test_refs_iterator__foreach_name(void)
 		git__free(name);
 	}
 
-	git_vector_free(&output);
+	git_vector_dispose(&output);
 }
 
 static int refs_foreach_name_cancel_cb(const char *name, void *payload)
